@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-package Task::Kensho::ExcelCSV; # git description: v0.38-52-gf6ad012
+package Task::Kensho::ExcelCSV; # git description: v0.39-52-ga265614
 # ABSTRACT: A Glimpse at an Enlightened Perl: Excel/CSV
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 __END__
 
@@ -17,7 +17,7 @@ Task::Kensho::ExcelCSV - A Glimpse at an Enlightened Perl: Excel/CSV
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -119,7 +119,7 @@ Chris Prather <chris@prather.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Rick Leir
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Olaf Alders Dan Book Rachel Kelly Shawn Sorichetti Rick Leir
 
 =over 4
 
@@ -137,6 +137,22 @@ Chris Nehren <apeiron@cpan.org>
 
 =item *
 
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Dan Book <grinnz@gmail.com>
+
+=item *
+
+Rachel Kelly <rkellyalso@gmail.com>
+
+=item *
+
+Shawn Sorichetti <shawn@coloredblocks.com>
+
+=item *
+
 Rick Leir <rleir@leirtech.com>
 
 =back
